@@ -1,2 +1,2 @@
 from . import (timeseries, timeseries_batch, frequencyseries, frequencyseries_batch, matchedfilter, matchedfilter_batch,
-               utils, tf_fft, tf_fft_batch)
+               utils, tf_fft, tf_fft_batch, utils)
